@@ -1,6 +1,9 @@
 test_that(
   "cast_shadow_shift_label returns nice error if variables aren't included",{
-  expect_error(cast_shadow_shift(airquality))
+  expect_snapshot(
+    error = TRUE,
+    cast_shadow_shift(airquality)
+    )
 })
 
 test_that("cast_shadow_shift_label returns a tibble",{
