@@ -1,6 +1,9 @@
 test_that("empty call provides an error", {
   df <- tibble::tibble(x = c("A", NA))
-  expect_error(replace_with_na_all(df))
+  expect_snapshot(
+    error = TRUE,
+    replace_with_na_all(df)
+    )
 })
 
 test_that("suggested single values are replaced with NAs", {
